@@ -3,9 +3,11 @@ import pymongo
 import logging
 from webob import Response
 from pyramid import registry
+from pyramid.view import view_config
 
 LOG = logging.getLogger('zopyx.gridfs')
 
+@view_config(name='gridfs')
 def gridfs_view(request):
 
     settings = request.registry.settings
@@ -13,11 +15,14 @@ def gridfs_view(request):
     port = settings.get('mongodb_port', '27017')
     database = settings.get('mongodb_database', 'test')
 
+    if len(request.subpath) != 2:
+        return Response(status=404)
+
+    collection, filename = request.subpath
+
     try:
         conn = pymongo.Connection(host, int(port))
         LOG.debug('Connected to mongodb://%s:%s/%s'  % (host, port, database))
-        filename = request.params.get('filename')
-        collection = request.params.get('collection', 'files')
 
         db = getattr(conn, database)
         fs = gridfs.GridFS(db, collection)
